@@ -19,7 +19,7 @@ from datetime import timedelta
 import psycopg2
 import psycopg2.extras
 from .testutils import unittest, ConnectingTestCase, skip_before_postgres
-from .testutils import skip_if_no_namedtuple
+from .testutils import skip_before_python, skip_if_no_namedtuple
 
 
 class ExtrasDictCursorTests(ConnectingTestCase):
@@ -39,7 +39,8 @@ class ExtrasDictCursorTests(ConnectingTestCase):
         self.assertTrue(isinstance(cur, psycopg2.extras.DictCursor))
         self.assertEqual(cur.name, None)
         # overridable
-        cur = self.conn.cursor('foo', cursor_factory=psycopg2.extras.NamedTupleCursor)
+        cur = self.conn.cursor('foo',
+            cursor_factory=psycopg2.extras.NamedTupleCursor)
         self.assertEqual(cur.name, 'foo')
         self.assertTrue(isinstance(cur, psycopg2.extras.NamedTupleCursor))
 
@@ -80,7 +81,6 @@ class ExtrasDictCursorTests(ConnectingTestCase):
         self.assertTrue(row[0] == 'bar')
         return row
 
-
     def testDictCursorWithPlainCursorRealFetchOne(self):
         self._testWithPlainCursorReal(lambda curs: curs.fetchone())
 
@@ -110,7 +110,6 @@ class ExtrasDictCursorTests(ConnectingTestCase):
         row = getter(curs)
         self.assertTrue(row['foo'] == 'bar')
 
-
     def testDictCursorWithNamedCursorFetchOne(self):
         self._testWithNamedCursor(lambda curs: curs.fetchone())
 
@@ -146,7 +145,6 @@ class ExtrasDictCursorTests(ConnectingTestCase):
         self.assertTrue(row['foo'] == 'bar')
         self.assertTrue(row[0] == 'bar')
 
-
     def testDictCursorRealWithNamedCursorFetchOne(self):
         self._testWithNamedCursorReal(lambda curs: curs.fetchone())
 
@@ -176,12 +174,12 @@ class ExtrasDictCursorTests(ConnectingTestCase):
         self._testIterRowNumber(curs)
 
     def _testWithNamedCursorReal(self, getter):
-        curs = self.conn.cursor('aname', cursor_factory=psycopg2.extras.RealDictCursor)
+        curs = self.conn.cursor('aname',
+            cursor_factory=psycopg2.extras.RealDictCursor)
         curs.execute("SELECT * FROM ExtrasDictCursorTests")
         row = getter(curs)
         self.assertTrue(row['foo'] == 'bar')
 
-
     def _testNamedCursorNotGreedy(self, curs):
         curs.itersize = 2
         curs.execute("""select clock_timestamp() as ts from generate_series(1,3)""")
@@ -235,7 +233,7 @@ class NamedTupleCursorTest(ConnectingTestCase):
         from psycopg2.extras import NamedTupleConnection
 
         try:
-            from collections import namedtuple
+            from collections import namedtuple      # noqa
         except ImportError:
             return
 
@@ -346,7 +344,7 @@ class NamedTupleCursorTest(ConnectingTestCase):
 
     def test_error_message(self):
         try:
-            from collections import namedtuple
+            from collections import namedtuple          # noqa
         except ImportError:
             # an import error somewhere
             from psycopg2.extras import NamedTupleConnection
@@ -384,12 +382,31 @@ class NamedTupleCursorTest(ConnectingTestCase):
         curs.execute("update nttest set s = s")
         self.assertRaises(psycopg2.ProgrammingError, curs.fetchall)
 
+    @skip_if_no_namedtuple
+    def test_bad_col_names(self):
+        curs = self.conn.cursor()
+        curs.execute('select 1 as "foo.bar_baz", 2 as "?column?", 3 as "3"')
+        rv = curs.fetchone()
+        self.assertEqual(rv.foo_bar_baz, 1)
+        self.assertEqual(rv.f_column_, 2)
+        self.assertEqual(rv.f3, 3)
+
+    @skip_before_python(3)
+    @skip_before_postgres(8)
+    @skip_if_no_namedtuple
+    def test_nonascii_name(self):
+        curs = self.conn.cursor()
+        curs.execute('select 1 as \xe5h\xe9')
+        rv = curs.fetchone()
+        self.assertEqual(getattr(rv, '\xe5h\xe9'), 1)
+
     @skip_if_no_namedtuple
     def test_minimal_generation(self):
         # Instrument the class to verify it gets called the minimum number of times.
         from psycopg2.extras import NamedTupleCursor
         f_orig = NamedTupleCursor._make_nt
         calls = [0]
+
         def f_patched(self_):
             calls[0] += 1
             return f_orig(self_)
